@@ -9,27 +9,27 @@
     </message>
     <message>
         <source>Current theme: </source>
-        <translation type="unfinished"></translation>
+        <translation>当前主题:</translation>
     </message>
     <message>
         <source>Export theme</source>
-        <translation type="unfinished"></translation>
+        <translation>导出主题</translation>
     </message>
     <message>
         <source>Import theme</source>
-        <translation type="unfinished"></translation>
+        <translation>导入主题</translation>
     </message>
     <message>
         <source>Exporting theme</source>
-        <translation type="unfinished"></translation>
+        <translation>导出主题</translation>
     </message>
     <message>
         <source>Select .tgz file to import</source>
-        <translation type="unfinished"></translation>
+        <translation>选择导入.tgz文件</translation>
     </message>
     <message>
         <source>Importing theme</source>
-        <translation type="unfinished"></translation>
+        <translation>导入主题</translation>
     </message>
     <message>
         <source>You can&apos;t delete a theme that&apos;s currently active.</source>
@@ -365,7 +365,7 @@
     </message>
     <message>
         <source>Save as new theme</source>
-        <translation>新主题另存为</translation>
+        <translation>另存为新主题</translation>
     </message>
 </context>
 <context>
